aboutsummaryrefslogtreecommitdiff
path: root/tests/util.scm
diff options
context:
space:
mode:
authorHugo Hörnquist <hugo@lysator.liu.se>2022-01-31 20:24:18 +0100
committerHugo Hörnquist <hugo@lysator.liu.se>2022-01-31 20:24:18 +0100
commit807409d41f8b1a4435ee1cf7ddc3d1a1b9116799 (patch)
tree41ce7d861f9048863f930b8a9227ca580da17911 /tests/util.scm
parentMove use2dot into scripts subdir. (diff)
downloadcalp-807409d41f8b1a4435ee1cf7ddc3d1a1b9116799.tar.gz
calp-807409d41f8b1a4435ee1cf7ddc3d1a1b9116799.tar.xz
Move stuff from calp/util to hnh/util.
This is the first (major) step in splitting the generally useful items into its own library.
Diffstat (limited to 'tests/util.scm')
-rw-r--r--tests/util.scm4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/util.scm b/tests/util.scm
index aa47a44f..45e69dd6 100644
--- a/tests/util.scm
+++ b/tests/util.scm
@@ -1,8 +1,8 @@
;;; Commentary:
;; Checks some prodecuders from (calp util)
;;; Code:
-(((calp util) filter-sorted set/r!
+(((hnh util) filter-sorted set/r!
find-min find-max span-upto
iterate ->string ->quoted-string path-append
begin1)
@@ -1,8 +1,8 @@
;;; Commentary:
-;; Checks some prodecuders from (calp util)
+;; Checks some prodecuders from (hnh util)
;;; Code: